import { defineNuxtModule, createResolver, addTemplate, addTypeTemplate, addPlugin, addVitePlugin, addWebpackPlugin } from '@nuxt/kit';
import rollupGraphql from '@rollup/plugin-graphql';
import { createUnplugin } from 'unplugin';

const module = defineNuxtModule({
  meta: {
    name: "nuxt-graphql-request",
    configKey: "graphql",
    compatibility: {
      nuxt: "^3.0.0"
    }
  },
  defaults: {
    includeNodeModules: false,
    options: {},
    clients: {}
  },
  setup(options) {
    const resolver = createResolver(import.meta.url);
    addTemplate({
      filename: "graphql.options.mjs",
      write: true,
      getContents: () => `
          export const options = ${JSON.stringify(options, void 0, 2)}
        `
    });
    addTypeTemplate({
      filename: "types/gql-file-import.d.ts",
      getContents: () => `// see: https://www.typescriptlang.org/docs/handbook/modules.html#wildcard-module-declarations
declare module '*.gql';
declare module '*.graphql';
declare module '*.graphqls';`
    });
    addPlugin(resolver.resolve("./runtime/plugin"));
    const rollupPlugin = rollupGraphql({
      exclude: options.includeNodeModules ? null : /node_modules/
    });
    const webpackPlugin = createUnplugin(() => rollupPlugin).webpack;
    addVitePlugin(rollupPlugin);
    addWebpackPlugin(webpackPlugin);
  }
});

export { module as default };
